@@ -296,7 +296,12 @@ babl_strdup (const char *s)
   ret = babl_malloc (strlen (s) + 1);
   if (!ret)
     babl_log ("args=(%s): failed", s);
+
+#ifndef _WIN64
   strcpy (ret, s);
+#else
+  strcpy_s (ret, strlen(s) + 1, s);
+#endif
 
 #if BABL_DEBUG_MEM
   babl_mutex_lock (babl_debug_mutex); 
@@ -318,8 +323,8 @@ babl_strcat (char       *dest,
              const char *src)
 {
   char *ret;
-  int   src_len;
-  int   dst_len;
+  size_t src_len;
+  size_t dst_len;
 
   if (NULL == src)
     return dest;
@@ -328,7 +333,11 @@ babl_strcat (char       *dest,
   if (!dest)
     {
       ret = babl_malloc (src_len + 1);
+#ifndef _WIN64
       strcpy (ret, src);
+#else
+      strcpy_s (ret, strlen(src) + 1, src);
+#endif
       return ret;
     }
   babl_assert (IS_BAI (dest));
@@ -344,7 +353,11 @@ babl_strcat (char       *dest,
       ret = babl_realloc (dest, new_size);
     }
 
+#ifndef _WIN64
   strcpy (&ret[dst_len], src);
+#else
+  strcpy_s (&ret[dst_len], strlen(src) + 1, src);
+#endif
   return ret;
 }
 
