@@ -825,6 +825,12 @@ babl_space_get (const Babl *babl,
   if(blue_trc)*blue_trc = space->trc[2];
 }
 
+int
+babl_space_is_rgb (const Babl *space)
+{
+  return space ? space->space.icc_type == BablICCTypeRGB : 0;
+}
+
 int
 babl_space_is_cmyk (const Babl *space)
 {
