@@ -101,14 +101,17 @@ babl_model_with_space (const char *name, const Babl *space);
 const Babl * babl_space (const char *name);
 
 typedef enum {
-  BABL_ICC_INTENT_PERCEPTUAL             = 0,
-  BABL_ICC_INTENT_RELATIVE_COLORIMETRIC  = 1,
-  BABL_ICC_INTENT_SATURATION             = 2,
-  BABL_ICC_INTENT_ABSOLUTE_COLORIMETRIC  = 3,
-  BABL_ICC_INTENT_PERFORMANCE            = 32
-  // black-point compensation toggle will be added if/when support exist in babl
+  BABL_ICC_INTENT_PERCEPTUAL               = 0,
+  BABL_ICC_INTENT_RELATIVE_COLORIMETRIC    = 1,
+  BABL_ICC_INTENT_SATURATION               = 2,
+  BABL_ICC_INTENT_ABSOLUTE_COLORIMETRIC    = 3,
+
+  // the following are flags:
+  BABL_ICC_INTENT_PERFORMANCE              = 32
 } BablIccIntent;
 
+#define BABL_ICC_INTENT_DEFAULT   (BABL_ICC_INTENT_RELATIVE_COLORIMETRIC)
+
 /**
  * babl_space_from_icc:
  * @icc_data: pointer to icc profile in memory
@@ -636,6 +639,11 @@ void babl_space_get (const Babl *space,
  * @blue_luminance: (out) (optional): Location for the blue luminance factor.
  *
  * Retrieve the relevant RGB luminance constants for a babl space.
+ *
+ * Note: these luminance coefficients should only ever be used on linear data.
+ * If your input @space is non-linear, you should convert your pixel values to
+ * the linearized variant of @space before making any computation with these
+ * coefficients. See #83.
  */
 void
 babl_space_get_rgb_luminance (const Babl *space,
@@ -664,7 +672,7 @@ int babl_model_is (const Babl *babl, const char *model_name);
  * like EXR GEGL chooses to load this lienar data as RGB and use the sRGB
  * TRC.
  *
- * Returns: pointer to ICC profile data.
+ * Returns: (transfer none) (array length=length) (element-type guint8): pointer to ICC profile data.
  */
 const char *babl_space_get_icc (const Babl *babl, int *length);
 
@@ -710,7 +718,28 @@ babl_space_from_rgbxyz_matrix (const char *name,
  */
 const char * babl_format_get_encoding (const Babl *babl);
 
+/**
+ * babl_space_is_rgb:
+ * @space:
+ *
+ * Returns: 1 if @space is RGB, 0 otherwise.
+ */
+int babl_space_is_rgb  (const Babl *space);
+
+/**
+ * babl_space_is_cmyk:
+ * @space:
+ *
+ * Returns: 1 if @space is CMYK, 0 otherwise.
+ */
 int babl_space_is_cmyk (const Babl *space);
+
+/**
+ * babl_space_is_gray:
+ * @space:
+ *
+ * Returns: 1 if @space is grayscale, 0 otherwise.
+ */
 int babl_space_is_gray (const Babl *space);
 
 typedef void (*BablFishProcess) (const Babl *babl, const char *src, char *dst, long n, void *data);
