@@ -584,14 +584,29 @@ babl_cli_get_space (const char    *path,
   FILE       *f;
   char       *icc_data;
   long        icc_length;
+  size_t      icc_read;
   const char *error = NULL;
+#ifdef _WIN64
+  char        errbuf[256];
+#endif
 
+#ifndef _WIN64
   f = fopen (path, "r");
+#else
+  if (fopen_s (&f, path, "r") != 0)
+    f = NULL;
+#endif
 
   if (f == NULL)
     {
+#ifndef _WIN64
+      fprintf(stderr, "babl: failed to open '%s': %s\n",
+          path, strerror(errno));
+#else
+      strerror_s(errbuf, sizeof(errbuf), errno);
       fprintf (stderr, "babl: failed to open '%s': %s\n",
-               path, strerror (errno));
+               path, errbuf);
+#endif
       return NULL;
     }
 
@@ -600,12 +615,28 @@ babl_cli_get_space (const char    *path,
   fseek (f, 0, SEEK_SET);
 
   icc_data = malloc (icc_length);
-  fread (icc_data, icc_length, 1, f);
+  icc_read = fread(icc_data, icc_length, 1, f);
+  if (icc_read != 1)
+    {
+#ifndef _WIN64
+      fprintf(stderr, "babl: failed to read '%s': %s\n",
+              path, strerror(errno));
+#else
+      strerror_s(errbuf, sizeof(errbuf), errno);
+      fprintf(stderr, "babl: failed to read '%s': %s\n",
+              path, errbuf);
+#endif
+      fclose(f);
+      free(icc_data);
+      return NULL;
+    }
 
   fclose (f);
 
   space = babl_space_from_icc (icc_data, icc_length, intent, &error);
 
+  free(icc_data);
+
   if (space == NULL)
     {
       fprintf (stderr, "babl: failed to load space from '%s': %s\n",
