@@ -248,15 +248,6 @@ conv_gaF_ga8 (const Babl    *conversion,
 #define conv_gF_g8          conv_F_8
 #define conv_gAF_gA8        conv_gaF_ga8
 
-static void
-conv_rgbaF_rgba16 (const Babl    *conversion,
-                   unsigned char *__restrict__ src, 
-                   unsigned char *__restrict__ dst, 
-                   long           samples)
-{
-  conv_F_16 (conversion, src, dst, samples * 4);
-}
-
 static void
 conv_rgbaF_rgbaD (const Babl    *conversion,
                   unsigned char *__restrict__ src, 
@@ -961,11 +952,11 @@ init (void)
   o (rgbAD, rgbAF);
   o (rgbaF, rgba8);
   o (rgba8, rgbaF);
-  o (rgbaF, rgba16);
+//  o (rgbaF, rgba16);
   o (rgba16, rgbaF);
   o (rgbAF, rgbA8);
   o (rgbA8, rgbAF);
-  o (rgbAF, rgbA16);
+//  o (rgbAF, rgbA16);
   o (rgbA16, rgbAF);
   o (rgbF, rgb8);
   o (rgb8, rgbF);
